@@ -13,7 +13,7 @@ Tabs_Config::Tabs_Config(QWidget *parent, const char *name)
     setObjectName(QString::fromLatin1(name));
     setupUi(this);
 
-    connect(kcfg_TabPlacement, QOverload<int>::of(&KComboBox::activated), this, &Tabs_Config::toggleCheckBoxes);
+    connect(kcfg_TabPlacement, QOverload<int>::of(&QComboBox::activated), this, &Tabs_Config::toggleCheckBoxes);
 }
 
 Tabs_Config::~Tabs_Config()
@@ -50,4 +50,4 @@ void Tabs_Config::toggleCheckBoxes(int activated)
     }
 }
 
-
+#include "moc_tabs_config.cpp"
