@@ -39,11 +39,7 @@
 #include <KMessageBox>
 #include <KIO/OpenUrlJob>
 #include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <QUrl>
 #include <KXMLGUIFactory>
 #include <KActionCollection>
@@ -101,7 +97,7 @@ void TabWidget::mouseReleaseEvent(QMouseEvent* event)
     if(event->button() == Qt::MiddleButton)
     {
         event->accept();
-        QPoint pos = event->globalPos();
+        QPoint pos = event->globalPosition().toPoint();
         int tabIndex = tabBar()->tabAt(tabBar()->mapFromGlobal(pos));
 
         if(tabIndex != -1)
@@ -127,8 +123,8 @@ ViewContainer::ViewContainer(MainWindow* window) : QAbstractItemModel(window)
 , m_queryViewCount(0)
 {
     // move existing entries to their new location
-    KConfigGroup appearanceStateConfig = KSharedConfig::openStateConfig()->group("Appearance");
-    KConfigGroup appearanceGrp = KSharedConfig::openConfig()->group("Appearance");
+    KConfigGroup appearanceStateConfig = KSharedConfig::openStateConfig()->group(QStringLiteral("Appearance"));
+    KConfigGroup appearanceGrp = KSharedConfig::openConfig()->group(QStringLiteral("Appearance"));
     appearanceGrp.moveValuesTo({"TreeSplitterSizes", "TopicSplitterSizes", "ChannelSplitterSizes"}, appearanceStateConfig);
 
     m_viewSpringLoader = new ViewSpringLoader(this);
@@ -1695,11 +1691,11 @@ void ViewContainer::unclutterTabs()
         m_tabWidget->removeTab(0);
     }
 
-    for (ChatWindow *view : qAsConst(topLevelViews)) {
+    for (ChatWindow *view : std::as_const(topLevelViews)) {
         m_tabWidget->insertTab(insertIndex(view), view, QIcon(), view->getName().replace(QLatin1Char('&'), QLatin1String("&&")));
     }
 
-    for (ChatWindow *view : qAsConst(nonTopLevelViews)) {
+    for (ChatWindow *view : std::as_const(nonTopLevelViews)) {
         m_tabWidget->insertTab(insertIndex(view), view, QIcon(), view->getName().replace(QLatin1Char('&'), QLatin1String("&&")));
     }
 
@@ -1818,7 +1814,7 @@ void ViewContainer::showNextActiveView()
         ChatWindow* prev = m_activeViewOrderList.first();
         ChatWindow* view = prev;
 
-        for (ChatWindow* activeView : qAsConst(m_activeViewOrderList)) {
+        for (ChatWindow* activeView : std::as_const(m_activeViewOrderList)) {
             if (activeView->currentTabNotification() < prev->currentTabNotification()) {
                 view = activeView;
             }
@@ -2594,11 +2590,7 @@ void ViewContainer::openLogFile(const QString& caption, const QString& file)
     if(Preferences::self()->useExternalLogViewer())
     {
         auto *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(file), QStringLiteral("text/plain"));
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_window));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_window));
-#endif
         job->start();
         return;
     }
